# cluster algebra visualization tool

This library provides a calculator for cluster algebras. 
Especially it is useful for calculating algebraic relations and visualizing quivers

## requirements

- python >= 3.8
- sympy
- pandas

## Installation

```bash
git clone
cd cluster-algebra
pip install -r requirements.txt
```
